pub struct BashCodeExecutionResultBlockParam {
pub content: Vec<BashCodeExecutionOutputBlockParam>,
pub return_code: i64,
pub stderr: String,
pub stdout: String,
pub type: BashCodeExecutionResultBlockParamType,
}Fields
content: Vec<BashCodeExecutionOutputBlockParam>return_code: i64stderr: Stringstdout: Stringtype: BashCodeExecutionResultBlockParamTypeTrait Implementations
Sourceimpl Clone for BashCodeExecutionResultBlockParam
impl Clone for BashCodeExecutionResultBlockParam
Sourcefn clone(&self) -> BashCodeExecutionResultBlockParam
fn clone(&self) -> BashCodeExecutionResultBlockParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BashCodeExecutionResultBlockParam
impl<'de> Deserialize<'de> for BashCodeExecutionResultBlockParam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<BashCodeExecutionResultBlockParam> for BashCodeExecutionToolResultBlockParamContent
impl From<BashCodeExecutionResultBlockParam> for BashCodeExecutionToolResultBlockParamContent
Sourcefn from(value: BashCodeExecutionResultBlockParam) -> Self
fn from(value: BashCodeExecutionResultBlockParam) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for BashCodeExecutionResultBlockParam
impl PartialEq for BashCodeExecutionResultBlockParam
Sourcefn eq(&self, other: &BashCodeExecutionResultBlockParam) -> bool
fn eq(&self, other: &BashCodeExecutionResultBlockParam) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BashCodeExecutionResultBlockParam
Sourceimpl TryFrom<BashCodeExecutionToolResultBlockParamContent> for BashCodeExecutionResultBlockParam
impl TryFrom<BashCodeExecutionToolResultBlockParamContent> for BashCodeExecutionResultBlockParam
Sourcefn try_from(
value: BashCodeExecutionToolResultBlockParamContent,
) -> Result<Self, Self::Error>
fn try_from( value: BashCodeExecutionToolResultBlockParamContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = BashCodeExecutionToolResultBlockParamContent
type Error = BashCodeExecutionToolResultBlockParamContent
The type returned in the event of a conversion error.