pub struct BashCodeExecutionToolResultErrorParam {
pub error_code: BashCodeExecutionToolResultErrorParamErrorCode,
pub type: BashCodeExecutionToolResultErrorParamType,
}Fields
error_code: BashCodeExecutionToolResultErrorParamErrorCodetype: BashCodeExecutionToolResultErrorParamTypeTrait Implementations
Sourceimpl Clone for BashCodeExecutionToolResultErrorParam
impl Clone for BashCodeExecutionToolResultErrorParam
Sourcefn clone(&self) -> BashCodeExecutionToolResultErrorParam
fn clone(&self) -> BashCodeExecutionToolResultErrorParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BashCodeExecutionToolResultErrorParam
impl<'de> Deserialize<'de> for BashCodeExecutionToolResultErrorParam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<BashCodeExecutionToolResultErrorParam> for BashCodeExecutionToolResultBlockParamContent
impl From<BashCodeExecutionToolResultErrorParam> for BashCodeExecutionToolResultBlockParamContent
Sourcefn from(value: BashCodeExecutionToolResultErrorParam) -> Self
fn from(value: BashCodeExecutionToolResultErrorParam) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for BashCodeExecutionToolResultErrorParam
impl PartialEq for BashCodeExecutionToolResultErrorParam
Sourcefn eq(&self, other: &BashCodeExecutionToolResultErrorParam) -> bool
fn eq(&self, other: &BashCodeExecutionToolResultErrorParam) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BashCodeExecutionToolResultErrorParam
Sourceimpl TryFrom<BashCodeExecutionToolResultBlockParamContent> for BashCodeExecutionToolResultErrorParam
impl TryFrom<BashCodeExecutionToolResultBlockParamContent> for BashCodeExecutionToolResultErrorParam
Sourcefn try_from(
value: BashCodeExecutionToolResultBlockParamContent,
) -> Result<Self, Self::Error>
fn try_from( value: BashCodeExecutionToolResultBlockParamContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = BashCodeExecutionToolResultBlockParamContent
type Error = BashCodeExecutionToolResultBlockParamContent
The type returned in the event of a conversion error.