pub struct CodeExecutionResultBlockParam {
pub content: Vec<CodeExecutionOutputBlockParam>,
pub return_code: i64,
pub stderr: String,
pub stdout: String,
pub type: CodeExecutionResultBlockParamType,
}Fields
content: Vec<CodeExecutionOutputBlockParam>return_code: i64stderr: Stringstdout: Stringtype: CodeExecutionResultBlockParamTypeTrait Implementations
Sourceimpl Clone for CodeExecutionResultBlockParam
impl Clone for CodeExecutionResultBlockParam
Sourcefn clone(&self) -> CodeExecutionResultBlockParam
fn clone(&self) -> CodeExecutionResultBlockParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CodeExecutionResultBlockParam
impl<'de> Deserialize<'de> for CodeExecutionResultBlockParam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<CodeExecutionResultBlockParam> for CodeExecutionToolResultBlockParamContent
impl From<CodeExecutionResultBlockParam> for CodeExecutionToolResultBlockParamContent
Sourcefn from(value: CodeExecutionResultBlockParam) -> Self
fn from(value: CodeExecutionResultBlockParam) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CodeExecutionResultBlockParam
impl PartialEq for CodeExecutionResultBlockParam
Sourcefn eq(&self, other: &CodeExecutionResultBlockParam) -> bool
fn eq(&self, other: &CodeExecutionResultBlockParam) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CodeExecutionResultBlockParam
Sourceimpl TryFrom<CodeExecutionToolResultBlockParamContent> for CodeExecutionResultBlockParam
impl TryFrom<CodeExecutionToolResultBlockParamContent> for CodeExecutionResultBlockParam
Sourcefn try_from(
value: CodeExecutionToolResultBlockParamContent,
) -> Result<Self, Self::Error>
fn try_from( value: CodeExecutionToolResultBlockParamContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = CodeExecutionToolResultBlockParamContent
type Error = CodeExecutionToolResultBlockParamContent
The type returned in the event of a conversion error.