pub struct CodeExecutionToolResultErrorParam {
pub error_code: CodeExecutionToolResultErrorParamErrorCode,
pub type: CodeExecutionToolResultErrorParamType,
}Fields
error_code: CodeExecutionToolResultErrorParamErrorCodetype: CodeExecutionToolResultErrorParamTypeTrait Implementations
Sourceimpl Clone for CodeExecutionToolResultErrorParam
impl Clone for CodeExecutionToolResultErrorParam
Sourcefn clone(&self) -> CodeExecutionToolResultErrorParam
fn clone(&self) -> CodeExecutionToolResultErrorParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CodeExecutionToolResultErrorParam
impl<'de> Deserialize<'de> for CodeExecutionToolResultErrorParam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<CodeExecutionToolResultErrorParam> for CodeExecutionToolResultBlockParamContent
impl From<CodeExecutionToolResultErrorParam> for CodeExecutionToolResultBlockParamContent
Sourcefn from(value: CodeExecutionToolResultErrorParam) -> Self
fn from(value: CodeExecutionToolResultErrorParam) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CodeExecutionToolResultErrorParam
impl PartialEq for CodeExecutionToolResultErrorParam
Sourcefn eq(&self, other: &CodeExecutionToolResultErrorParam) -> bool
fn eq(&self, other: &CodeExecutionToolResultErrorParam) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CodeExecutionToolResultErrorParam
Sourceimpl TryFrom<CodeExecutionToolResultBlockParamContent> for CodeExecutionToolResultErrorParam
impl TryFrom<CodeExecutionToolResultBlockParamContent> for CodeExecutionToolResultErrorParam
Sourcefn try_from(
value: CodeExecutionToolResultBlockParamContent,
) -> Result<Self, Self::Error>
fn try_from( value: CodeExecutionToolResultBlockParamContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = CodeExecutionToolResultBlockParamContent
type Error = CodeExecutionToolResultBlockParamContent
The type returned in the event of a conversion error.