pub struct EncryptedCodeExecutionResultBlockParam {
pub content: Vec<CodeExecutionOutputBlockParam>,
pub encrypted_stdout: String,
pub return_code: i64,
pub stderr: String,
pub type: EncryptedCodeExecutionResultBlockParamType,
}Expand description
PFC + web_search 加密 stdout 的代码执行结果。
Fields
content: Vec<CodeExecutionOutputBlockParam>encrypted_stdout: Stringreturn_code: i64stderr: Stringtype: EncryptedCodeExecutionResultBlockParamTypeTrait Implementations
Sourceimpl Clone for EncryptedCodeExecutionResultBlockParam
impl Clone for EncryptedCodeExecutionResultBlockParam
Sourcefn clone(&self) -> EncryptedCodeExecutionResultBlockParam
fn clone(&self) -> EncryptedCodeExecutionResultBlockParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for EncryptedCodeExecutionResultBlockParam
impl<'de> Deserialize<'de> for EncryptedCodeExecutionResultBlockParam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<EncryptedCodeExecutionResultBlockParam> for CodeExecutionToolResultBlockParamContent
impl From<EncryptedCodeExecutionResultBlockParam> for CodeExecutionToolResultBlockParamContent
Sourcefn from(value: EncryptedCodeExecutionResultBlockParam) -> Self
fn from(value: EncryptedCodeExecutionResultBlockParam) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for EncryptedCodeExecutionResultBlockParam
impl PartialEq for EncryptedCodeExecutionResultBlockParam
Sourcefn eq(&self, other: &EncryptedCodeExecutionResultBlockParam) -> bool
fn eq(&self, other: &EncryptedCodeExecutionResultBlockParam) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EncryptedCodeExecutionResultBlockParam
Sourceimpl TryFrom<CodeExecutionToolResultBlockParamContent> for EncryptedCodeExecutionResultBlockParam
impl TryFrom<CodeExecutionToolResultBlockParamContent> for EncryptedCodeExecutionResultBlockParam
Sourcefn try_from(
value: CodeExecutionToolResultBlockParamContent,
) -> Result<Self, Self::Error>
fn try_from( value: CodeExecutionToolResultBlockParamContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = CodeExecutionToolResultBlockParamContent
type Error = CodeExecutionToolResultBlockParamContent
The type returned in the event of a conversion error.