pub struct TextEditorCodeExecutionCreateResultBlock {
pub is_file_update: bool,
pub type: TextEditorCodeExecutionCreateResultBlockType,
}Fields
is_file_update: booltype: TextEditorCodeExecutionCreateResultBlockTypeTrait Implementations
Sourceimpl Clone for TextEditorCodeExecutionCreateResultBlock
impl Clone for TextEditorCodeExecutionCreateResultBlock
Sourcefn clone(&self) -> TextEditorCodeExecutionCreateResultBlock
fn clone(&self) -> TextEditorCodeExecutionCreateResultBlock
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TextEditorCodeExecutionCreateResultBlock
impl<'de> Deserialize<'de> for TextEditorCodeExecutionCreateResultBlock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<TextEditorCodeExecutionCreateResultBlock> for TextEditorCodeExecutionToolResultBlockContent
impl From<TextEditorCodeExecutionCreateResultBlock> for TextEditorCodeExecutionToolResultBlockContent
Sourcefn from(value: TextEditorCodeExecutionCreateResultBlock) -> Self
fn from(value: TextEditorCodeExecutionCreateResultBlock) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for TextEditorCodeExecutionCreateResultBlock
impl PartialEq for TextEditorCodeExecutionCreateResultBlock
Sourcefn eq(&self, other: &TextEditorCodeExecutionCreateResultBlock) -> bool
fn eq(&self, other: &TextEditorCodeExecutionCreateResultBlock) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TextEditorCodeExecutionCreateResultBlock
Sourceimpl TryFrom<TextEditorCodeExecutionToolResultBlockContent> for TextEditorCodeExecutionCreateResultBlock
impl TryFrom<TextEditorCodeExecutionToolResultBlockContent> for TextEditorCodeExecutionCreateResultBlock
Sourcefn try_from(
value: TextEditorCodeExecutionToolResultBlockContent,
) -> Result<Self, Self::Error>
fn try_from( value: TextEditorCodeExecutionToolResultBlockContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = TextEditorCodeExecutionToolResultBlockContent
type Error = TextEditorCodeExecutionToolResultBlockContent
The type returned in the event of a conversion error.