pub struct TextEditorCodeExecutionCreateResultBlockParam {
pub is_file_update: bool,
pub type: TextEditorCodeExecutionCreateResultBlockParamType,
}Fields
is_file_update: booltype: TextEditorCodeExecutionCreateResultBlockParamTypeTrait Implementations
Sourceimpl Clone for TextEditorCodeExecutionCreateResultBlockParam
impl Clone for TextEditorCodeExecutionCreateResultBlockParam
Sourcefn clone(&self) -> TextEditorCodeExecutionCreateResultBlockParam
fn clone(&self) -> TextEditorCodeExecutionCreateResultBlockParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TextEditorCodeExecutionCreateResultBlockParam
impl<'de> Deserialize<'de> for TextEditorCodeExecutionCreateResultBlockParam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<TextEditorCodeExecutionCreateResultBlockParam> for TextEditorCodeExecutionToolResultBlockParamContent
impl From<TextEditorCodeExecutionCreateResultBlockParam> for TextEditorCodeExecutionToolResultBlockParamContent
Sourcefn from(value: TextEditorCodeExecutionCreateResultBlockParam) -> Self
fn from(value: TextEditorCodeExecutionCreateResultBlockParam) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for TextEditorCodeExecutionCreateResultBlockParam
impl PartialEq for TextEditorCodeExecutionCreateResultBlockParam
Sourcefn eq(&self, other: &TextEditorCodeExecutionCreateResultBlockParam) -> bool
fn eq(&self, other: &TextEditorCodeExecutionCreateResultBlockParam) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TextEditorCodeExecutionCreateResultBlockParam
Sourceimpl TryFrom<TextEditorCodeExecutionToolResultBlockParamContent> for TextEditorCodeExecutionCreateResultBlockParam
impl TryFrom<TextEditorCodeExecutionToolResultBlockParamContent> for TextEditorCodeExecutionCreateResultBlockParam
Sourcefn try_from(
value: TextEditorCodeExecutionToolResultBlockParamContent,
) -> Result<Self, Self::Error>
fn try_from( value: TextEditorCodeExecutionToolResultBlockParamContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = TextEditorCodeExecutionToolResultBlockParamContent
type Error = TextEditorCodeExecutionToolResultBlockParamContent
The type returned in the event of a conversion error.