pub struct TextEditorCodeExecutionStrReplaceResultBlock {
pub lines: Vec<String>,
pub new_lines: i64,
pub new_start: i64,
pub old_lines: i64,
pub old_start: i64,
pub type: TextEditorCodeExecutionStrReplaceResultBlockType,
}Fields
lines: Vec<String>new_lines: i64new_start: i64old_lines: i64old_start: i64type: TextEditorCodeExecutionStrReplaceResultBlockTypeTrait Implementations
Sourceimpl Clone for TextEditorCodeExecutionStrReplaceResultBlock
impl Clone for TextEditorCodeExecutionStrReplaceResultBlock
Sourcefn clone(&self) -> TextEditorCodeExecutionStrReplaceResultBlock
fn clone(&self) -> TextEditorCodeExecutionStrReplaceResultBlock
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TextEditorCodeExecutionStrReplaceResultBlock
impl<'de> Deserialize<'de> for TextEditorCodeExecutionStrReplaceResultBlock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<TextEditorCodeExecutionStrReplaceResultBlock> for TextEditorCodeExecutionToolResultBlockContent
impl From<TextEditorCodeExecutionStrReplaceResultBlock> for TextEditorCodeExecutionToolResultBlockContent
Sourcefn from(value: TextEditorCodeExecutionStrReplaceResultBlock) -> Self
fn from(value: TextEditorCodeExecutionStrReplaceResultBlock) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for TextEditorCodeExecutionStrReplaceResultBlock
impl PartialEq for TextEditorCodeExecutionStrReplaceResultBlock
Sourcefn eq(&self, other: &TextEditorCodeExecutionStrReplaceResultBlock) -> bool
fn eq(&self, other: &TextEditorCodeExecutionStrReplaceResultBlock) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TextEditorCodeExecutionStrReplaceResultBlock
Sourceimpl TryFrom<TextEditorCodeExecutionToolResultBlockContent> for TextEditorCodeExecutionStrReplaceResultBlock
impl TryFrom<TextEditorCodeExecutionToolResultBlockContent> for TextEditorCodeExecutionStrReplaceResultBlock
Sourcefn try_from(
value: TextEditorCodeExecutionToolResultBlockContent,
) -> Result<Self, Self::Error>
fn try_from( value: TextEditorCodeExecutionToolResultBlockContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = TextEditorCodeExecutionToolResultBlockContent
type Error = TextEditorCodeExecutionToolResultBlockContent
The type returned in the event of a conversion error.