pub struct TextEditorCodeExecutionToolResultError {
pub error_code: TextEditorCodeExecutionToolResultErrorErrorCode,
pub error_message: String,
pub type: TextEditorCodeExecutionToolResultErrorType,
}Fields
error_code: TextEditorCodeExecutionToolResultErrorErrorCodeerror_message: Stringtype: TextEditorCodeExecutionToolResultErrorTypeTrait Implementations
Sourceimpl Clone for TextEditorCodeExecutionToolResultError
impl Clone for TextEditorCodeExecutionToolResultError
Sourcefn clone(&self) -> TextEditorCodeExecutionToolResultError
fn clone(&self) -> TextEditorCodeExecutionToolResultError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TextEditorCodeExecutionToolResultError
impl<'de> Deserialize<'de> for TextEditorCodeExecutionToolResultError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<TextEditorCodeExecutionToolResultError> for TextEditorCodeExecutionToolResultBlockContent
impl From<TextEditorCodeExecutionToolResultError> for TextEditorCodeExecutionToolResultBlockContent
Sourcefn from(value: TextEditorCodeExecutionToolResultError) -> Self
fn from(value: TextEditorCodeExecutionToolResultError) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for TextEditorCodeExecutionToolResultError
impl PartialEq for TextEditorCodeExecutionToolResultError
Sourcefn eq(&self, other: &TextEditorCodeExecutionToolResultError) -> bool
fn eq(&self, other: &TextEditorCodeExecutionToolResultError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TextEditorCodeExecutionToolResultError
Sourceimpl TryFrom<TextEditorCodeExecutionToolResultBlockContent> for TextEditorCodeExecutionToolResultError
impl TryFrom<TextEditorCodeExecutionToolResultBlockContent> for TextEditorCodeExecutionToolResultError
Sourcefn try_from(
value: TextEditorCodeExecutionToolResultBlockContent,
) -> Result<Self, Self::Error>
fn try_from( value: TextEditorCodeExecutionToolResultBlockContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = TextEditorCodeExecutionToolResultBlockContent
type Error = TextEditorCodeExecutionToolResultBlockContent
The type returned in the event of a conversion error.