pub struct TextEditorCodeExecutionToolResultErrorParam {
pub error_code: TextEditorCodeExecutionToolResultErrorParamErrorCode,
pub type: TextEditorCodeExecutionToolResultErrorParamType,
pub error_message: Option<String>,
}Fields
error_code: TextEditorCodeExecutionToolResultErrorParamErrorCodetype: TextEditorCodeExecutionToolResultErrorParamTypeerror_message: Option<String>Trait Implementations
Sourceimpl Clone for TextEditorCodeExecutionToolResultErrorParam
impl Clone for TextEditorCodeExecutionToolResultErrorParam
Sourcefn clone(&self) -> TextEditorCodeExecutionToolResultErrorParam
fn clone(&self) -> TextEditorCodeExecutionToolResultErrorParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TextEditorCodeExecutionToolResultErrorParam
impl<'de> Deserialize<'de> for TextEditorCodeExecutionToolResultErrorParam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<TextEditorCodeExecutionToolResultErrorParam> for TextEditorCodeExecutionToolResultBlockParamContent
impl From<TextEditorCodeExecutionToolResultErrorParam> for TextEditorCodeExecutionToolResultBlockParamContent
Sourcefn from(value: TextEditorCodeExecutionToolResultErrorParam) -> Self
fn from(value: TextEditorCodeExecutionToolResultErrorParam) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for TextEditorCodeExecutionToolResultErrorParam
impl PartialEq for TextEditorCodeExecutionToolResultErrorParam
Sourcefn eq(&self, other: &TextEditorCodeExecutionToolResultErrorParam) -> bool
fn eq(&self, other: &TextEditorCodeExecutionToolResultErrorParam) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TextEditorCodeExecutionToolResultErrorParam
Sourceimpl TryFrom<TextEditorCodeExecutionToolResultBlockParamContent> for TextEditorCodeExecutionToolResultErrorParam
impl TryFrom<TextEditorCodeExecutionToolResultBlockParamContent> for TextEditorCodeExecutionToolResultErrorParam
Sourcefn try_from(
value: TextEditorCodeExecutionToolResultBlockParamContent,
) -> Result<Self, Self::Error>
fn try_from( value: TextEditorCodeExecutionToolResultBlockParamContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = TextEditorCodeExecutionToolResultBlockParamContent
type Error = TextEditorCodeExecutionToolResultBlockParamContent
The type returned in the event of a conversion error.