pub struct TextEditorCodeExecutionViewResultBlock {
pub content: String,
pub file_type: TextEditorCodeExecutionViewResultBlockFileType,
pub num_lines: i64,
pub start_line: i64,
pub total_lines: i64,
pub type: TextEditorCodeExecutionViewResultBlockType,
}Fields
content: Stringfile_type: TextEditorCodeExecutionViewResultBlockFileTypenum_lines: i64start_line: i64total_lines: i64type: TextEditorCodeExecutionViewResultBlockTypeTrait Implementations
Sourceimpl Clone for TextEditorCodeExecutionViewResultBlock
impl Clone for TextEditorCodeExecutionViewResultBlock
Sourcefn clone(&self) -> TextEditorCodeExecutionViewResultBlock
fn clone(&self) -> TextEditorCodeExecutionViewResultBlock
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TextEditorCodeExecutionViewResultBlock
impl<'de> Deserialize<'de> for TextEditorCodeExecutionViewResultBlock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<TextEditorCodeExecutionViewResultBlock> for TextEditorCodeExecutionToolResultBlockContent
impl From<TextEditorCodeExecutionViewResultBlock> for TextEditorCodeExecutionToolResultBlockContent
Sourcefn from(value: TextEditorCodeExecutionViewResultBlock) -> Self
fn from(value: TextEditorCodeExecutionViewResultBlock) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for TextEditorCodeExecutionViewResultBlock
impl PartialEq for TextEditorCodeExecutionViewResultBlock
Sourcefn eq(&self, other: &TextEditorCodeExecutionViewResultBlock) -> bool
fn eq(&self, other: &TextEditorCodeExecutionViewResultBlock) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TextEditorCodeExecutionViewResultBlock
Sourceimpl TryFrom<TextEditorCodeExecutionToolResultBlockContent> for TextEditorCodeExecutionViewResultBlock
impl TryFrom<TextEditorCodeExecutionToolResultBlockContent> for TextEditorCodeExecutionViewResultBlock
Sourcefn try_from(
value: TextEditorCodeExecutionToolResultBlockContent,
) -> Result<Self, Self::Error>
fn try_from( value: TextEditorCodeExecutionToolResultBlockContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = TextEditorCodeExecutionToolResultBlockContent
type Error = TextEditorCodeExecutionToolResultBlockContent
The type returned in the event of a conversion error.