pub struct TextEditorCodeExecutionViewResultBlockParam {
pub content: String,
pub file_type: TextEditorCodeExecutionViewResultBlockParamFileType,
pub type: TextEditorCodeExecutionViewResultBlockParamType,
pub num_lines: Option<i64>,
pub start_line: Option<i64>,
pub total_lines: Option<i64>,
}Fields
content: Stringfile_type: TextEditorCodeExecutionViewResultBlockParamFileTypetype: TextEditorCodeExecutionViewResultBlockParamTypenum_lines: Option<i64>start_line: Option<i64>total_lines: Option<i64>Trait Implementations
Sourceimpl Clone for TextEditorCodeExecutionViewResultBlockParam
impl Clone for TextEditorCodeExecutionViewResultBlockParam
Sourcefn clone(&self) -> TextEditorCodeExecutionViewResultBlockParam
fn clone(&self) -> TextEditorCodeExecutionViewResultBlockParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TextEditorCodeExecutionViewResultBlockParam
impl<'de> Deserialize<'de> for TextEditorCodeExecutionViewResultBlockParam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<TextEditorCodeExecutionViewResultBlockParam> for TextEditorCodeExecutionToolResultBlockParamContent
impl From<TextEditorCodeExecutionViewResultBlockParam> for TextEditorCodeExecutionToolResultBlockParamContent
Sourcefn from(value: TextEditorCodeExecutionViewResultBlockParam) -> Self
fn from(value: TextEditorCodeExecutionViewResultBlockParam) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for TextEditorCodeExecutionViewResultBlockParam
impl PartialEq for TextEditorCodeExecutionViewResultBlockParam
Sourcefn eq(&self, other: &TextEditorCodeExecutionViewResultBlockParam) -> bool
fn eq(&self, other: &TextEditorCodeExecutionViewResultBlockParam) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TextEditorCodeExecutionViewResultBlockParam
Sourceimpl TryFrom<TextEditorCodeExecutionToolResultBlockParamContent> for TextEditorCodeExecutionViewResultBlockParam
impl TryFrom<TextEditorCodeExecutionToolResultBlockParamContent> for TextEditorCodeExecutionViewResultBlockParam
Sourcefn try_from(
value: TextEditorCodeExecutionToolResultBlockParamContent,
) -> Result<Self, Self::Error>
fn try_from( value: TextEditorCodeExecutionToolResultBlockParamContent, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = TextEditorCodeExecutionToolResultBlockParamContent
type Error = TextEditorCodeExecutionToolResultBlockParamContent
The type returned in the event of a conversion error.