pub enum ChatCompletionToolChoiceOptionVariant0 {
None,
Auto,
Required,
}Expand description
Tool choice mode
none means the model will not call any tool and instead generates a message. auto means the model can pick between generating a message or calling one or more tools. required means the model must call one or more tools.
Variants