pub enum CreateChatCompletionRequestFunctionCall {
CreateChatCompletionRequestFunctionCallVariant0(CreateChatCompletionRequestFunctionCallVariant0),
ChatCompletionFunctionCallOption(ChatCompletionFunctionCallOption),
}๐Deprecated
Deprecated in favor of tool_choice.
Controls which (if any) function is called by the model.
none means the model will not call a function and instead generates a
message.
auto means the model can pick between generating a message or calling a
function.
Specifying a particular function via {"name": "my_function"} forces the
model to call that function.
none is the default when no functions are present. auto is the default
if functions are present.
Variants
CreateChatCompletionRequestFunctionCallVariant0(CreateChatCompletionRequestFunctionCallVariant0)
๐Deprecated
ChatCompletionFunctionCallOption(ChatCompletionFunctionCallOption)
๐Deprecated