pub enum CreateChatCompletionRequestFunctionCallVariant0 {
None,
Auto,
}Expand description
none means the model will not call a function and instead generates a message. auto means the model can pick between generating a message or calling a function.
Variants