pub enum CreateChatCompletionRequestPrediction {
PredictionContent(PredictionContent),
}Expand description
Configuration for a Predicted Output, which can greatly improve response times when large parts of the model response are known ahead of time. This is most common when you are regenerating a file with only minor changes to most of the content.
Variants
PredictionContent(PredictionContent)