pub enum CreateChatCompletionRequestResponseFormat {
ResponseFormatText(ResponseFormatText),
ResponseFormatJsonSchema(ResponseFormatJsonSchema),
ResponseFormatJsonObject(ResponseFormatJsonObject),
}Expand description
An object specifying the format that the model must output.
Setting to { "type": "json_schema", "json_schema": {...} } enables
Structured Outputs which ensures the model will match your supplied JSON
schema. Learn more in the Structured Outputs
guide.
Setting to { "type": "json_object" } enables the older JSON mode, which
ensures the message the model generates is valid JSON. Using json_schema
is preferred for models that support it.
Variants
ResponseFormatText(ResponseFormatText)
ResponseFormatJsonSchema(ResponseFormatJsonSchema)
ResponseFormatJsonObject(ResponseFormatJsonObject)