pub enum PredictionContentContent {
PredictionContentContentVariant0(String),
PredictionContentContentVariant1(Vec<ChatCompletionRequestMessageContentPartText>),
}Expand description
The content that should be matched when generating a model response. If generated tokens would match this content, the entire model response can be returned much more quickly.
Variants
PredictionContentContentVariant0(String)
PredictionContentContentVariant1(Vec<ChatCompletionRequestMessageContentPartText>)