pub struct ChatCompletionAllowedToolsChoice {
pub type: ChatCompletionAllowedToolsChoiceType,
pub allowed_tools: ChatCompletionAllowedTools,
}Expand description
Allowed tools
Constrains the tools available to the model to a pre-defined set.
Fields
type: ChatCompletionAllowedToolsChoiceTypeAllowed tool configuration type. Always allowed_tools.
allowed_tools: ChatCompletionAllowedToolsTrait Implementations
Sourceimpl Clone for ChatCompletionAllowedToolsChoice
impl Clone for ChatCompletionAllowedToolsChoice
Sourcefn clone(&self) -> ChatCompletionAllowedToolsChoice
fn clone(&self) -> ChatCompletionAllowedToolsChoice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ChatCompletionAllowedToolsChoice
impl<'de> Deserialize<'de> for ChatCompletionAllowedToolsChoice
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ChatCompletionAllowedToolsChoice> for ChatCompletionToolChoiceOption
impl From<ChatCompletionAllowedToolsChoice> for ChatCompletionToolChoiceOption
Sourcefn from(value: ChatCompletionAllowedToolsChoice) -> Self
fn from(value: ChatCompletionAllowedToolsChoice) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ChatCompletionAllowedToolsChoice
impl PartialEq for ChatCompletionAllowedToolsChoice
Sourcefn eq(&self, other: &ChatCompletionAllowedToolsChoice) -> bool
fn eq(&self, other: &ChatCompletionAllowedToolsChoice) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChatCompletionAllowedToolsChoice