pub struct ChatCompletionFunctions {
pub description: Option<String>,
pub name: String,
pub parameters: Option<FunctionParameters>,
}👎Deprecated
Fields
description: Option<String>👎Deprecated
A description of what the function does, used by the model to choose when and how to call the function.
name: String👎Deprecated
The name of the function to be called. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.
parameters: Option<FunctionParameters>👎Deprecated