pub struct ChatCompletionMessageToolCallChunkFunction {
pub name: Option<String>,
pub arguments: Option<String>,
}Fields
name: Option<String>The name of the function to call.
arguments: Option<String>The arguments to call the function with, as generated by the model in JSON format. Note that the model does not always generate valid JSON, and may hallucinate parameters not defined by your function schema. Validate the arguments in your code before calling your function.