pub struct ChatCompletionRequestAssistantMessage {
pub content: Option<ChatCompletionRequestAssistantMessageContent>,
pub refusal: Option<ChatCompletionRequestAssistantMessageRefusal>,
pub role: ChatCompletionRequestAssistantMessageRole,
pub name: Option<String>,
pub audio: Option<ChatCompletionRequestAssistantMessageAudio>,
pub tool_calls: Option<ChatCompletionMessageToolCalls>,
pub function_call: Option<ChatCompletionRequestAssistantMessageFunctionCall>,
pub reasoning_content: Option<String>,
}Expand description
Assistant message
Messages sent by the model in response to user messages.
Fields
content: Option<ChatCompletionRequestAssistantMessageContent>refusal: Option<ChatCompletionRequestAssistantMessageRefusal>role: ChatCompletionRequestAssistantMessageRoleThe role of the messages author, in this case assistant.
name: Option<String>An optional name for the participant. Provides the model information to differentiate between participants of the same role.
audio: Option<ChatCompletionRequestAssistantMessageAudio>tool_calls: Option<ChatCompletionMessageToolCalls>function_call: Option<ChatCompletionRequestAssistantMessageFunctionCall>reasoning_content: Option<String>兼容厂商扩展(DeepSeek-v4-pro 等):上一轮 assistant 的思考链文本,thinking 模式下必须回放给服务端。OpenAI 官方忽略此字段。