pub struct ChatCompletionRequestAssistantMessageAudioVariant0 {
pub id: String,
}Expand description
Data about a previous audio response from the model. Learn more.
Fields
id: StringUnique identifier for a previous audio response from the model.