pub struct ChatCompletionRequestDeveloperMessage {
pub content: ChatCompletionRequestDeveloperMessageContent,
pub role: ChatCompletionRequestDeveloperMessageRole,
pub name: Option<String>,
}Expand description
Developer message
Developer-provided instructions that the model should follow, regardless of
messages sent by the user. With o1 models and newer, developer messages
replace the previous system messages.
Fields
content: ChatCompletionRequestDeveloperMessageContentThe contents of the developer message.
role: ChatCompletionRequestDeveloperMessageRoleThe role of the messages author, in this case developer.
name: Option<String>An optional name for the participant. Provides the model information to differentiate between participants of the same role.