pub struct ChatCompletionRequestMessageContentPartAudio {
pub type: ChatCompletionRequestMessageContentPartAudioType,
pub input_audio: ChatCompletionRequestMessageContentPartAudioInputAudio,
}Expand description
Audio content part
Learn about audio inputs.
Fields
type: ChatCompletionRequestMessageContentPartAudioTypeThe type of the content part. Always input_audio.
input_audio: ChatCompletionRequestMessageContentPartAudioInputAudioTrait Implementations
Sourceimpl Clone for ChatCompletionRequestMessageContentPartAudio
impl Clone for ChatCompletionRequestMessageContentPartAudio
Sourcefn clone(&self) -> ChatCompletionRequestMessageContentPartAudio
fn clone(&self) -> ChatCompletionRequestMessageContentPartAudio
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ChatCompletionRequestMessageContentPartAudio
impl<'de> Deserialize<'de> for ChatCompletionRequestMessageContentPartAudio
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ChatCompletionRequestMessageContentPartAudio> for ChatCompletionRequestUserMessageContentPart
impl From<ChatCompletionRequestMessageContentPartAudio> for ChatCompletionRequestUserMessageContentPart
Sourcefn from(value: ChatCompletionRequestMessageContentPartAudio) -> Self
fn from(value: ChatCompletionRequestMessageContentPartAudio) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ChatCompletionRequestMessageContentPartAudio
impl PartialEq for ChatCompletionRequestMessageContentPartAudio
Sourcefn eq(&self, other: &ChatCompletionRequestMessageContentPartAudio) -> bool
fn eq(&self, other: &ChatCompletionRequestMessageContentPartAudio) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChatCompletionRequestMessageContentPartAudio
Sourceimpl TryFrom<ChatCompletionRequestUserMessageContentPart> for ChatCompletionRequestMessageContentPartAudio
impl TryFrom<ChatCompletionRequestUserMessageContentPart> for ChatCompletionRequestMessageContentPartAudio
Sourcefn try_from(
value: ChatCompletionRequestUserMessageContentPart,
) -> Result<Self, Self::Error>
fn try_from( value: ChatCompletionRequestUserMessageContentPart, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = ChatCompletionRequestUserMessageContentPart
type Error = ChatCompletionRequestUserMessageContentPart
The type returned in the event of a conversion error.