pub struct ChatCompletionRequestMessageContentPartFile {
pub type: ChatCompletionRequestMessageContentPartFileType,
pub file: ChatCompletionRequestMessageContentPartFileFile,
}Expand description
File content part
Learn about file inputs for text generation.
Fields
type: ChatCompletionRequestMessageContentPartFileTypeThe type of the content part. Always file.
file: ChatCompletionRequestMessageContentPartFileFileTrait Implementations
Sourceimpl Clone for ChatCompletionRequestMessageContentPartFile
impl Clone for ChatCompletionRequestMessageContentPartFile
Sourcefn clone(&self) -> ChatCompletionRequestMessageContentPartFile
fn clone(&self) -> ChatCompletionRequestMessageContentPartFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ChatCompletionRequestMessageContentPartFile
impl<'de> Deserialize<'de> for ChatCompletionRequestMessageContentPartFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ChatCompletionRequestMessageContentPartFile> for ChatCompletionRequestUserMessageContentPart
impl From<ChatCompletionRequestMessageContentPartFile> for ChatCompletionRequestUserMessageContentPart
Sourcefn from(value: ChatCompletionRequestMessageContentPartFile) -> Self
fn from(value: ChatCompletionRequestMessageContentPartFile) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ChatCompletionRequestMessageContentPartFile
impl PartialEq for ChatCompletionRequestMessageContentPartFile
Sourcefn eq(&self, other: &ChatCompletionRequestMessageContentPartFile) -> bool
fn eq(&self, other: &ChatCompletionRequestMessageContentPartFile) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChatCompletionRequestMessageContentPartFile
Sourceimpl TryFrom<ChatCompletionRequestUserMessageContentPart> for ChatCompletionRequestMessageContentPartFile
impl TryFrom<ChatCompletionRequestUserMessageContentPart> for ChatCompletionRequestMessageContentPartFile
Sourcefn try_from(
value: ChatCompletionRequestUserMessageContentPart,
) -> Result<Self, Self::Error>
fn try_from( value: ChatCompletionRequestUserMessageContentPart, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = ChatCompletionRequestUserMessageContentPart
type Error = ChatCompletionRequestUserMessageContentPart
The type returned in the event of a conversion error.