pub struct ChatCompletionRequestMessageContentPartImage {
pub type: ChatCompletionRequestMessageContentPartImageType,
pub image_url: ChatCompletionRequestMessageContentPartImageImageUrl,
}Expand description
Image content part
Learn about image inputs.
Fields
type: ChatCompletionRequestMessageContentPartImageTypeThe type of the content part.
image_url: ChatCompletionRequestMessageContentPartImageImageUrlTrait Implementations
Sourceimpl Clone for ChatCompletionRequestMessageContentPartImage
impl Clone for ChatCompletionRequestMessageContentPartImage
Sourcefn clone(&self) -> ChatCompletionRequestMessageContentPartImage
fn clone(&self) -> ChatCompletionRequestMessageContentPartImage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ChatCompletionRequestMessageContentPartImage
impl<'de> Deserialize<'de> for ChatCompletionRequestMessageContentPartImage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ChatCompletionRequestMessageContentPartImage> for ChatCompletionRequestUserMessageContentPart
impl From<ChatCompletionRequestMessageContentPartImage> for ChatCompletionRequestUserMessageContentPart
Sourcefn from(value: ChatCompletionRequestMessageContentPartImage) -> Self
fn from(value: ChatCompletionRequestMessageContentPartImage) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ChatCompletionRequestMessageContentPartImage
impl PartialEq for ChatCompletionRequestMessageContentPartImage
Sourcefn eq(&self, other: &ChatCompletionRequestMessageContentPartImage) -> bool
fn eq(&self, other: &ChatCompletionRequestMessageContentPartImage) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChatCompletionRequestMessageContentPartImage
Sourceimpl TryFrom<ChatCompletionRequestUserMessageContentPart> for ChatCompletionRequestMessageContentPartImage
impl TryFrom<ChatCompletionRequestUserMessageContentPart> for ChatCompletionRequestMessageContentPartImage
Sourcefn try_from(
value: ChatCompletionRequestUserMessageContentPart,
) -> Result<Self, Self::Error>
fn try_from( value: ChatCompletionRequestUserMessageContentPart, ) -> Result<Self, Self::Error>
Errors
Returns the original enum value if it does not match the
#variant_ident variant.
Sourcetype Error = ChatCompletionRequestUserMessageContentPart
type Error = ChatCompletionRequestUserMessageContentPart
The type returned in the event of a conversion error.