pub struct ChatCompletionRequestSystemMessage {
pub content: ChatCompletionRequestSystemMessageContent,
pub role: ChatCompletionRequestSystemMessageRole,
pub name: Option<String>,
}Expand description
System message
Developer-provided instructions that the model should follow, regardless of
messages sent by the user. With o1 models and newer, use developer messages
for this purpose instead.
Fields
content: ChatCompletionRequestSystemMessageContentThe contents of the system message.
role: ChatCompletionRequestSystemMessageRoleThe role of the messages author, in this case system.
name: Option<String>An optional name for the participant. Provides the model information to differentiate between participants of the same role.