pub struct ChatCompletionResponseMessage {
pub content: ChatCompletionResponseMessageContent,
pub refusal: ChatCompletionResponseMessageRefusal,
pub tool_calls: Option<ChatCompletionMessageToolCalls>,
pub annotations: Option<Vec<ChatCompletionResponseMessageAnnotations>>,
pub role: ChatCompletionResponseMessageRole,
pub function_call: Option<ChatCompletionResponseMessageFunctionCall>,
pub audio: Option<ChatCompletionResponseMessageAudio>,
}Expand description
A chat completion message generated by the model.
Fields
content: ChatCompletionResponseMessageContentrefusal: ChatCompletionResponseMessageRefusaltool_calls: Option<ChatCompletionMessageToolCalls>annotations: Option<Vec<ChatCompletionResponseMessageAnnotations>>Annotations for the message, when applicable, as when using the web search tool.
role: ChatCompletionResponseMessageRoleThe role of the author of this message.
function_call: Option<ChatCompletionResponseMessageFunctionCall>👎Deprecated
Deprecated and replaced by tool_calls. The name and arguments of a function that should be called, as generated by the model.
audio: Option<ChatCompletionResponseMessageAudio>Trait Implementations
Sourceimpl Clone for ChatCompletionResponseMessage
impl Clone for ChatCompletionResponseMessage
Sourcefn clone(&self) -> ChatCompletionResponseMessage
fn clone(&self) -> ChatCompletionResponseMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ChatCompletionResponseMessage
impl<'de> Deserialize<'de> for ChatCompletionResponseMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ChatCompletionResponseMessage
impl PartialEq for ChatCompletionResponseMessage
Sourcefn eq(&self, other: &ChatCompletionResponseMessage) -> bool
fn eq(&self, other: &ChatCompletionResponseMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChatCompletionResponseMessage