pub struct ChatCompletionResponseMessageAudioVariant0 {
pub id: String,
pub expires_at: i64,
pub data: String,
pub transcript: String,
}Expand description
If the audio output modality is requested, this object contains data about the audio response from the model. Learn more.
Fields
id: StringUnique identifier for this audio response.
expires_at: i64The Unix timestamp (in seconds) for when this audio response will no longer be accessible on the server for use in multi-turn conversations.
data: StringBase64 encoded audio bytes generated by the model, in the format specified in the request.
transcript: StringTranscript of the audio generated by the model.