pub struct ChatCompletionStreamResponseDeltaFunctionCall {
pub arguments: Option<String>,
pub name: Option<String>,
}๐Deprecated
Deprecated and replaced by tool_calls. The name and arguments of a function that should be called, as generated by the model.
Fields
arguments: Option<String>๐Deprecated
The arguments to call the function with, as generated by the model in JSON format. Note that the model does not always generate valid JSON, and may hallucinate parameters not defined by your function schema. Validate the arguments in your code before calling your function.
name: Option<String>๐Deprecated
The name of the function to call.