pub struct ChatCompletionTokenLogprob {
pub token: String,
pub logprob: f64,
pub bytes: ChatCompletionTokenLogprobBytes,
pub top_logprobs: Vec<ChatCompletionTokenLogprobTopLogprobs>,
}Fields
token: StringThe token.
logprob: f64The log probability of this token, if it is within the top 20 most likely tokens. Otherwise, the value -9999.0 is used to signify that the token is very unlikely.
bytes: ChatCompletionTokenLogprobBytestop_logprobs: Vec<ChatCompletionTokenLogprobTopLogprobs>List of the most likely tokens and their log probability, at this token position. The number of entries may be fewer than the requested top_logprobs.