pub struct ChatCompletionTokenLogprobTopLogprobs {
pub token: String,
pub logprob: f64,
pub bytes: ChatCompletionTokenLogprobTopLogprobsBytes,
}Fields
token: StringThe token.
logprob: f64The log probability of this token, if it is within the top 20 most likely tokens. Otherwise, the value -9999.0 is used to signify that the token is very unlikely.
bytes: ChatCompletionTokenLogprobTopLogprobsBytesTrait Implementations
Sourceimpl Clone for ChatCompletionTokenLogprobTopLogprobs
impl Clone for ChatCompletionTokenLogprobTopLogprobs
Sourcefn clone(&self) -> ChatCompletionTokenLogprobTopLogprobs
fn clone(&self) -> ChatCompletionTokenLogprobTopLogprobs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ChatCompletionTokenLogprobTopLogprobs
impl<'de> Deserialize<'de> for ChatCompletionTokenLogprobTopLogprobs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ChatCompletionTokenLogprobTopLogprobs
impl PartialEq for ChatCompletionTokenLogprobTopLogprobs
Sourcefn eq(&self, other: &ChatCompletionTokenLogprobTopLogprobs) -> bool
fn eq(&self, other: &ChatCompletionTokenLogprobTopLogprobs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChatCompletionTokenLogprobTopLogprobs