pub struct ChatCompletionTool {
pub type: ChatCompletionToolType,
pub function: FunctionObject,
}Expand description
Function tool
A function tool that can be used to generate a response.
Fields
type: ChatCompletionToolTypeThe type of the tool. Currently, only function is supported.
function: FunctionObjectTrait Implementations
Sourceimpl Clone for ChatCompletionTool
impl Clone for ChatCompletionTool
Sourcefn clone(&self) -> ChatCompletionTool
fn clone(&self) -> ChatCompletionTool
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChatCompletionTool
impl Debug for ChatCompletionTool
Sourceimpl<'de> Deserialize<'de> for ChatCompletionTool
impl<'de> Deserialize<'de> for ChatCompletionTool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ChatCompletionTool> for CreateChatCompletionRequestTools
impl From<ChatCompletionTool> for CreateChatCompletionRequestTools
Sourcefn from(value: ChatCompletionTool) -> Self
fn from(value: ChatCompletionTool) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ChatCompletionTool
impl PartialEq for ChatCompletionTool
Sourcefn eq(&self, other: &ChatCompletionTool) -> bool
fn eq(&self, other: &ChatCompletionTool) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ChatCompletionTool
impl Serialize for ChatCompletionTool
impl StructuralPartialEq for ChatCompletionTool