pub struct CompletionUsageCompletionTokensDetails {
pub accepted_prediction_tokens: Option<i64>,
pub audio_tokens: Option<i64>,
pub reasoning_tokens: Option<i64>,
pub rejected_prediction_tokens: Option<i64>,
}Expand description
Breakdown of tokens used in a completion.
Fields
accepted_prediction_tokens: Option<i64>When using Predicted Outputs, the number of tokens in the prediction that appeared in the completion.
audio_tokens: Option<i64>Audio input tokens generated by the model.
reasoning_tokens: Option<i64>Tokens generated by the model for reasoning.
rejected_prediction_tokens: Option<i64>When using Predicted Outputs, the number of tokens in the prediction that did not appear in the completion. However, like reasoning tokens, these tokens are still counted in the total completion tokens for purposes of billing, output, and context window limits.