pub struct CreateChatCompletionRequestWebSearchOptions {
pub user_location: Option<CreateChatCompletionRequestWebSearchOptionsUserLocation>,
pub search_context_size: Option<WebSearchContextSize>,
}Expand description
Web search
This tool searches the web for relevant results to use in a response. Learn more about the web search tool.
Fields
user_location: Option<CreateChatCompletionRequestWebSearchOptionsUserLocation>Approximate location parameters for the search.
search_context_size: Option<WebSearchContextSize>Trait Implementations
Sourceimpl Clone for CreateChatCompletionRequestWebSearchOptions
impl Clone for CreateChatCompletionRequestWebSearchOptions
Sourcefn clone(&self) -> CreateChatCompletionRequestWebSearchOptions
fn clone(&self) -> CreateChatCompletionRequestWebSearchOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CreateChatCompletionRequestWebSearchOptions
impl<'de> Deserialize<'de> for CreateChatCompletionRequestWebSearchOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CreateChatCompletionRequestWebSearchOptions
impl PartialEq for CreateChatCompletionRequestWebSearchOptions
Sourcefn eq(&self, other: &CreateChatCompletionRequestWebSearchOptions) -> bool
fn eq(&self, other: &CreateChatCompletionRequestWebSearchOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateChatCompletionRequestWebSearchOptions