pub struct CreateChatCompletionResponse {
pub id: String,
pub choices: Vec<CreateChatCompletionResponseChoices>,
pub created: i64,
pub model: String,
pub service_tier: Option<ServiceTier>,
pub system_fingerprint: Option<String>,
pub object: CreateChatCompletionResponseObject,
pub usage: Option<CompletionUsage>,
}Expand description
Represents a chat completion response returned by model, based on the provided input.
Fields
id: StringA unique identifier for the chat completion.
choices: Vec<CreateChatCompletionResponseChoices>A list of chat completion choices. Can be more than one if n is greater than 1.
created: i64The Unix timestamp (in seconds) of when the chat completion was created.
model: StringThe model used for the chat completion.
service_tier: Option<ServiceTier>system_fingerprint: Option<String>👎Deprecated
This fingerprint represents the backend configuration that the model runs with.
Can be used in conjunction with the seed request parameter to understand when backend changes have been made that might impact determinism.
object: CreateChatCompletionResponseObjectThe object type, which is always chat.completion.
usage: Option<CompletionUsage>Trait Implementations
Sourceimpl Clone for CreateChatCompletionResponse
impl Clone for CreateChatCompletionResponse
Sourcefn clone(&self) -> CreateChatCompletionResponse
fn clone(&self) -> CreateChatCompletionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateChatCompletionResponse
impl Debug for CreateChatCompletionResponse
Sourceimpl<'de> Deserialize<'de> for CreateChatCompletionResponse
impl<'de> Deserialize<'de> for CreateChatCompletionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CreateChatCompletionResponse
impl PartialEq for CreateChatCompletionResponse
Sourcefn eq(&self, other: &CreateChatCompletionResponse) -> bool
fn eq(&self, other: &CreateChatCompletionResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateChatCompletionResponse