pub struct CreateChatCompletionResponseChoices {
pub finish_reason: CreateChatCompletionResponseChoicesFinishReason,
pub index: i64,
pub message: ChatCompletionResponseMessage,
pub logprobs: CreateChatCompletionResponseChoicesLogprobs,
}Fields
finish_reason: CreateChatCompletionResponseChoicesFinishReasonThe reason the model stopped generating tokens. This will be stop if the model hit a natural stop point or a provided stop sequence,
length if the maximum number of tokens specified in the request was reached,
content_filter if content was omitted due to a flag from our content filters,
tool_calls if the model called a tool, or function_call (deprecated) if the model called a function.
index: i64The index of the choice in the list of choices.
message: ChatCompletionResponseMessagelogprobs: CreateChatCompletionResponseChoicesLogprobsTrait Implementations
Sourceimpl Clone for CreateChatCompletionResponseChoices
impl Clone for CreateChatCompletionResponseChoices
Sourcefn clone(&self) -> CreateChatCompletionResponseChoices
fn clone(&self) -> CreateChatCompletionResponseChoices
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CreateChatCompletionResponseChoices
impl<'de> Deserialize<'de> for CreateChatCompletionResponseChoices
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CreateChatCompletionResponseChoices
impl PartialEq for CreateChatCompletionResponseChoices
Sourcefn eq(&self, other: &CreateChatCompletionResponseChoices) -> bool
fn eq(&self, other: &CreateChatCompletionResponseChoices) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateChatCompletionResponseChoices