pub struct CreateModelResponseProperties {
pub metadata: Option<Metadata>,
pub top_logprobs: Option<CreateModelResponsePropertiesTopLogprobs>,
pub temperature: Option<CreateModelResponsePropertiesTemperature>,
pub top_p: Option<CreateModelResponsePropertiesTopP>,
pub user: Option<String>,
pub safety_identifier: Option<String>,
pub prompt_cache_key: Option<String>,
pub service_tier: Option<ServiceTier>,
pub prompt_cache_retention: Option<CreateModelResponsePropertiesPromptCacheRetention>,
}Fields
metadata: Option<Metadata>top_logprobs: Option<CreateModelResponsePropertiesTopLogprobs>temperature: Option<CreateModelResponsePropertiesTemperature>top_p: Option<CreateModelResponsePropertiesTopP>user: Option<String>This field is being replaced by safety_identifier and prompt_cache_key. Use prompt_cache_key instead to maintain caching optimizations.
A stable identifier for your end-users.
Used to boost cache hit rates by better bucketing similar requests and to help OpenAI detect and prevent abuse. Learn more.
safety_identifier: Option<String>A stable identifier used to help detect users of your application that may be violating OpenAI’s usage policies. The IDs should be a string that uniquely identifies each user, with a maximum length of 64 characters. We recommend hashing their username or email address, in order to avoid sending us any identifying information. Learn more.
prompt_cache_key: Option<String>Used by OpenAI to cache responses for similar requests to optimize your cache hit rates. Replaces the user field. Learn more.
service_tier: Option<ServiceTier>prompt_cache_retention: Option<CreateModelResponsePropertiesPromptCacheRetention>Trait Implementations
Sourceimpl Clone for CreateModelResponseProperties
impl Clone for CreateModelResponseProperties
Sourcefn clone(&self) -> CreateModelResponseProperties
fn clone(&self) -> CreateModelResponseProperties
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<'de> Deserialize<'de> for CreateModelResponseProperties
impl<'de> Deserialize<'de> for CreateModelResponseProperties
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for CreateModelResponseProperties
impl PartialEq for CreateModelResponseProperties
Sourcefn eq(&self, other: &CreateModelResponseProperties) -> bool
fn eq(&self, other: &CreateModelResponseProperties) -> bool
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateModelResponseProperties