pub struct FunctionObject {
pub description: Option<String>,
pub name: String,
pub parameters: Option<FunctionParameters>,
pub strict: Option<FunctionObjectStrict>,
}Fields
description: Option<String>A description of what the function does, used by the model to choose when and how to call the function.
name: StringThe name of the function to be called. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.
parameters: Option<FunctionParameters>strict: Option<FunctionObjectStrict>Trait Implementations
Sourceimpl Clone for FunctionObject
impl Clone for FunctionObject
Sourcefn clone(&self) -> FunctionObject
fn clone(&self) -> FunctionObject
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionObject
impl Debug for FunctionObject
Sourceimpl<'de> Deserialize<'de> for FunctionObject
impl<'de> Deserialize<'de> for FunctionObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FunctionObject
impl PartialEq for FunctionObject
Sourcefn eq(&self, other: &FunctionObject) -> bool
fn eq(&self, other: &FunctionObject) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FunctionObject
impl Serialize for FunctionObject
impl StructuralPartialEq for FunctionObject