pub struct Model {
pub id: String,
pub created: i64,
pub object: ModelObject,
pub owned_by: String,
}Expand description
Model
Describes an OpenAI model offering that can be used with the API.
Fields
id: StringThe model identifier, which can be referenced in the API endpoints.
created: i64The Unix timestamp (in seconds) when the model was created.
object: ModelObjectThe object type, which is always “model”.
owned_by: StringThe organization that owns the model.