pub struct ModelResponseProperties {
pub metadata: Option<Metadata>,
pub top_logprobs: Option<ModelResponsePropertiesTopLogprobs>,
pub temperature: Option<ModelResponsePropertiesTemperature>,
pub top_p: Option<ModelResponsePropertiesTopP>,
pub user: Option<String>,
pub safety_identifier: Option<String>,
pub prompt_cache_key: Option<String>,
pub service_tier: Option<ServiceTier>,
pub prompt_cache_retention: Option<ModelResponsePropertiesPromptCacheRetention>,
}Fields
metadata: Option<Metadata>top_logprobs: Option<ModelResponsePropertiesTopLogprobs>temperature: Option<ModelResponsePropertiesTemperature>top_p: Option<ModelResponsePropertiesTopP>user: Option<String>This field is being replaced by safety_identifier and prompt_cache_key. Use prompt_cache_key instead to maintain caching optimizations.
A stable identifier for your end-users.
Used to boost cache hit rates by better bucketing similar requests and to help OpenAI detect and prevent abuse. Learn more.
safety_identifier: Option<String>A stable identifier used to help detect users of your application that may be violating OpenAI’s usage policies. The IDs should be a string that uniquely identifies each user, with a maximum length of 64 characters. We recommend hashing their username or email address, in order to avoid sending us any identifying information. Learn more.
prompt_cache_key: Option<String>Used by OpenAI to cache responses for similar requests to optimize your cache hit rates. Replaces the user field. Learn more.
service_tier: Option<ServiceTier>prompt_cache_retention: Option<ModelResponsePropertiesPromptCacheRetention>Trait Implementations
Sourceimpl Clone for ModelResponseProperties
impl Clone for ModelResponseProperties
Sourcefn clone(&self) -> ModelResponseProperties
fn clone(&self) -> ModelResponseProperties
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ModelResponseProperties
impl Debug for ModelResponseProperties
Sourceimpl<'de> Deserialize<'de> for ModelResponseProperties
impl<'de> Deserialize<'de> for ModelResponseProperties
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for ModelResponseProperties
impl PartialEq for ModelResponseProperties
Sourcefn eq(&self, other: &ModelResponseProperties) -> bool
fn eq(&self, other: &ModelResponseProperties) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ModelResponseProperties
impl Serialize for ModelResponseProperties
impl StructuralPartialEq for ModelResponseProperties