pub struct PredictionContent {
pub type: PredictionContentType,
pub content: PredictionContentContent,
}Expand description
Static Content
Static predicted output content, such as the content of a text file that is being regenerated.
Fields
type: PredictionContentTypeThe type of the predicted content you want to provide. This type is
currently always content.
content: PredictionContentContentThe content that should be matched when generating a model response. If generated tokens would match this content, the entire model response can be returned much more quickly.