pub struct WebSearchLocation {
pub country: Option<String>,
pub region: Option<String>,
pub city: Option<String>,
pub timezone: Option<String>,
}Expand description
Web search location
Approximate location parameters for the search.
Fields
country: Option<String>The two-letter
ISO country code of the user,
e.g. US.
region: Option<String>Free text input for the region of the user, e.g. California.
city: Option<String>Free text input for the city of the user, e.g. San Francisco.
timezone: Option<String>The IANA timezone
of the user, e.g. America/Los_Angeles.