ChatCompletionRequestAssistantMessageFunctionCallVariant0

Struct ChatCompletionRequestAssistantMessageFunctionCallVariant0 

pub struct ChatCompletionRequestAssistantMessageFunctionCallVariant0 {
    pub arguments: String,
    pub name: String,
}
๐Ÿ‘ŽDeprecated
Deprecated and replaced by tool_calls. The name and arguments of a function that should be called, as generated by the model.

Fields

arguments: String
๐Ÿ‘ŽDeprecated

The arguments to call the function with, as generated by the model in JSON format. Note that the model does not always generate valid JSON, and may hallucinate parameters not defined by your function schema. Validate the arguments in your code before calling your function.

name: String
๐Ÿ‘ŽDeprecated

The name of the function to call.